@@ -83,7 +83,6 @@ class DenMune():
                   train_truth=None, test_truth=None, 
                   file_2d ='_temp_2d', k_nearest=1, 
                   rgn_tsne=False, prop_step=0,
-                  show_analyzer=True
                   ):     
          
         if train_data is None:
@@ -100,15 +99,6 @@ class DenMune():
         if test_truth is not None:
            self.data_indicator += 8  
 
-        """
-        if  self.data_indicator <= 7: # train_truth is given
-           self.data_type = 'train'
-        elif  self.data_indicator <= 11: # test data is given
-           self.data_type = 'test'
-        elif  self.data_indicator == 15: # test_truth is given
-           self.data_type = 'augmented'   
-        """
-
         self.analyzer = {}
         self.analyzer['n_points'] = {}
         if isinstance(train_data, pd.DataFrame):
@@ -150,10 +140,6 @@ class DenMune():
         self.analyzer["n_points"]["weak"]["succeeded to merge"] = 0
         self.analyzer["n_points"]["weak"]["failed to merge"] = 0
         self.analyzer["n_points"]["dim"] = data.shape[1]
-        self.analyzer["validity"] = {}
-        self.analyzer["validity"]['train'] = {}
-        self.analyzer["validity"]['test'] = {}
-        self.analyzer["validity"]['augmented'] = {}
         self.analyzer["n_clusters"] = {}
         self.analyzer["n_clusters"]["actual"] = 0
         self.analyzer["n_clusters"]["detected"] = 0
@@ -179,7 +165,6 @@ class DenMune():
         
         self.alg_name = 'denmune'
         self.prop_step = prop_step
-        self.show_analyzer = show_analyzer
         self.data = data
         self.train_data = train_data
         self.test_data = test_data
@@ -524,6 +509,7 @@ class DenMune():
     def fit_predict(self,
                     validate=True, show_plots=True,
                     show_noise=True, data_type=None,
+                    show_analyzer=True
                     ):
         validity_scores = []
         solution_file = 'solution.txt'
@@ -544,44 +530,57 @@ class DenMune():
         labels_dic ['train'] = self.train_pred
         labels_dic ['test'] = self.test_pred
         
+      
+       
+
+
         if self.test_data is not None:
             self.labels_pred = np.append(self.train_pred, self.test_pred, axis = 0)
         else:
             self.labels_pred = self.train_pred 
 
-
         if self.data_indicator >= 3: 
-            print ("Plotting dataset Groundtruth")
+
+            if show_analyzer:
+                print ("Plotting dataset Groundtruth")
             self.plot_clusters(show_plots=show_plots, show_noise=show_noise, data_type='ground')
 
         if validate and self.data_indicator >= 1: 
       
            if self.data_indicator >= 3:
+               self.analyzer["validity"] = {}
                validity_scores = self.validate_Clusters(data_type='train') 
          
-           print ('Plotting train data')  
+           if show_analyzer:
+               print ('Plotting train data')  
            self.plot_clusters(show_plots=show_plots, show_noise=show_noise, data_type='train')
-           if self.show_analyzer:
-               self.show_Analyzer(root='Validating train data')   
+           if show_analyzer:
+              self.analyzer["validity"]['train'] = {}
+              self.show_Analyzer(root='Validating train data')   
 
            if self.data_indicator == 15:
                validity_scores = self.validate_Clusters(data_type='test') 
-               if self.show_analyzer:
+               if show_analyzer:
+                   self.analyzer["validity"]['test'] = {}
                    self.show_Analyzer(self.analyzer['validity']['test'], root='Validating test data')
           
            if self.data_indicator > 3:
-               print ('Plotting test data')  
+               if show_analyzer:
+                   print ('Plotting test data')  
                self.plot_clusters(show_plots=show_plots, show_noise=show_noise, data_type='test')
-          
+
+           """"
            if self.data_indicator == 15:
                validity_scores = self.validate_Clusters(data_type='augmented') 
-               if self.show_analyzer:
+               if show_analyzer:
+                   self.analyzer["validity"]['augmented'] = {}
                    self.show_Analyzer(self.analyzer['validity']['augmented'], root='Validating augmented data (train & test)')
-
+           
            if self.data_indicator > 3: 
-               print ('Plotting augmented data (train & test)')  
+               if show_analyzer:
+                   print ('Plotting augmented data (train & test)')  
                self.plot_clusters(show_plots=show_plots, show_noise=show_noise, data_type='augmented')
-         
+           """
         return labels_dic, self.analyzer['validity']
         
 
@@ -792,7 +791,7 @@ class DenMune():
           palette = sns.color_palette( 'deep',  np.unique(labels).max()+2 ) #deep, dark, bright, muted, pastel, colorblind
                   
           if self.prop_step:
-              colors = [palette[x] if x > 0 else ( (0.0, 0.0, 0.0) if x == -1 else (0.0, 0.0, 0.0)) for x in labels]
+              colors = [palette[x] if x >= 0 else ( (0.0, 0.0, 0.0) if x == -1 else (0.0, 0.0, 0.0)) for x in labels]
               v = 0
               for c in colors:
                   if (c[0]+c[1] + c[2]) > 0.0:  # outlier :: keep it in black 
@@ -803,7 +802,7 @@ class DenMune():
       
           else:
               if show_noise == False:
-                  colors = [palette[x] if x > 0 else (1.0, 1.0, 1.0) for x in labels] # noise points wont be printed due to x > 0 , else (1.0, 1.0, 1.0)
+                  colors = [palette[x] if x >= 0 else (1.0, 1.0, 1.0) for x in labels] # noise points wont be printed due to x > 0 , else (1.0, 1.0, 1.0)
               else :
                   colors = [palette[x] if x >= 0 else ( (0.0, 0.0, 0.0) if x == -1 else (0.9, 0.9, 0.9)) for x in labels] # noise points wont be printed due to x > 0 , else (1.0, 1.0, 1.0)
 
